@@ -16,6 +16,8 @@ class HistorianApi:
         headers = {'Authorization': self.Authentication.Token.access_token, "Accept":"application/x-protobuf"}
         print(url)
         response = DeserializeResponse(requests.get(url, headers=headers))
+        if response.errors:            
+            return response
         return response.content.historianDatas.items
     
     def GetHistorianDataRange(self, twinRefId, startTime:datetime, endTime: datetime):        
@@ -23,6 +25,8 @@ class HistorianApi:
         print(url)
         headers = {'Authorization': self.Authentication.Token.access_token, "Accept":"application/x-protobuf"}
         response = DeserializeResponse(requests.get(url, headers=headers))
+        if response.errors:            
+            return response
         return response.content.historianDatas.items
     
         
\ No newline at end of file
